# IpsecConnectionIpv4Block

An IP address range that defines a network range. Use CIDR notation when entering the block 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**ipv4_address_block** | **str** | ipv4 CIDR block | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


